@@ -2,8 +2,8 @@ package WWW::MobileCarrierJP::ThirdForce::UserAgent;
 use WWW::MobileCarrierJP::Declare;
 
 parse_one( 
-    urls => ['http://creation.mb.softbank.jp/terminal/index.html'],
-    xpath => q(//tr[@bgcolor="#FFFFFF"]/td[@rowspan="5"]/..),
+    urls => ['http://creation.mb.softbank.jp/mc/terminal/terminal_info/terminal_useragent.html'],
+    xpath => q(//tr/td[@rowspan="5"]/..),
     scraper => scraper {
         col 1 => 'model'      => 'TEXT';
         col 2 => 'user_agent' => ['TEXT', sub { s/\s+$//; }];
